@@ -84,6 +84,8 @@
 ( cd opt/kde/share/doc/HTML/et/kandy ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kcalc ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kcalc ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kdcop ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kdcop ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kdesu ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kdesu ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kcron ; rm -rf common )
@@ -116,6 +118,8 @@
 ( cd opt/kde/share/doc/HTML/et/ksysv ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/ktron ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/ktron ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kttsd ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kttsd ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kuser ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kuser ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kview ; rm -rf common )
@@ -168,6 +172,8 @@
 ( cd opt/kde/share/doc/HTML/et/ksirtet ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/konquest ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/konquest ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/akregator ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/akregator ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kspaceduel ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kturtle ; rm -rf common )
@@ -192,6 +198,8 @@
 ( cd opt/kde/share/doc/HTML/et/flashkard ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kbackgammon ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/knetattach ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/knetattach ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kaddressbook ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/common ; rm -rf fdl-license )
@@ -216,6 +224,8 @@
 ( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/6.png 6.png )
 ( cd opt/kde/share/doc/HTML/et/common ; rm -rf 7.png )
 ( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/7.png 7.png )
+( cd opt/kde/share/doc/HTML/et/common ; rm -rf top-right-konqueror.png )
+( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/top-right-konqueror.png top-right-konqueror.png )
 ( cd opt/kde/share/doc/HTML/et/common ; rm -rf 8.png )
 ( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/8.png 8.png )
 ( cd opt/kde/share/doc/HTML/et/common ; rm -rf 9.png )
@@ -246,6 +256,8 @@
 ( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/footer.html footer.html )
 ( cd opt/kde/share/doc/HTML/et/common ; rm -rf kde-common.css )
 ( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
+( cd opt/kde/share/doc/HTML/et/common ; rm -rf bottom-left.png )
+( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/bottom-left.png bottom-left.png )
 ( cd opt/kde/share/doc/HTML/et/common ; rm -rf appheader.html )
 ( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/appheader.html appheader.html )
 ( cd opt/kde/share/doc/HTML/et/common ; rm -rf doctop1.png )
@@ -258,8 +270,12 @@
 ( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
 ( cd opt/kde/share/doc/HTML/et/common ; rm -rf docheadergears.png )
 ( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
+( cd opt/kde/share/doc/HTML/et/common ; rm -rf top-middle.png )
+( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/top-middle.png top-middle.png )
 ( cd opt/kde/share/doc/HTML/et/common ; rm -rf fdl-license.html )
 ( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
+( cd opt/kde/share/doc/HTML/et/common ; rm -rf bottom-right.png )
+( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/bottom-right.png bottom-right.png )
 ( cd opt/kde/share/doc/HTML/et/common ; rm -rf doctop1a.png )
 ( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
 ( cd opt/kde/share/doc/HTML/et/common ; rm -rf 10.png )
@@ -276,6 +292,10 @@
 ( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
 ( cd opt/kde/share/doc/HTML/et/common ; rm -rf header.html )
 ( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/header.html header.html )
+( cd opt/kde/share/doc/HTML/et/common ; rm -rf bottom-middle.png )
+( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/bottom-middle.png bottom-middle.png )
+( cd opt/kde/share/doc/HTML/et/common ; rm -rf top-left.png )
+( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/top-left.png top-left.png )
 ( cd opt/kde/share/doc/HTML/et/common ; rm -rf gpl-license )
 ( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/gpl-license gpl-license )
 ( cd opt/kde/share/doc/HTML/et/common ; rm -rf kde-localised.css.template )
@@ -286,6 +306,8 @@
 ( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
 ( cd opt/kde/share/doc/HTML/et/common ; rm -rf artistic-license.html )
 ( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
+( cd opt/kde/share/doc/HTML/et/multisynk ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/multisynk ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kcontrol/kdm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kcontrol/kdm ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kcontrol/smb ; rm -rf common )
@@ -396,8 +418,34 @@
 ( cd opt/kde/share/doc/HTML/et/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kicker-applets ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/konq-plugins/crashes ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/konq-plugins/crashes ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/konq-plugins/babel ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/konq-plugins/babel ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/konq-plugins/kuick ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/konq-plugins/kuick ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/konq-plugins/webarchiver ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/konq-plugins/webarchiver ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/konq-plugins/domtreeviewer ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/konq-plugins/domtreeviewer ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/konq-plugins/smbmounter ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/konq-plugins/smbmounter ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/konq-plugins/imgallery ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/konq-plugins/imgallery ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/konq-plugins/khtmlsettings ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/konq-plugins/khtmlsettings ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/konq-plugins/validators ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/konq-plugins/validators ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/konq-plugins ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/konq-plugins/fsview ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/konq-plugins/fsview ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/konq-plugins/uachanger ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/konq-plugins/uachanger ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/konq-plugins/mediaplayer ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/konq-plugins/mediaplayer ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/konq-plugins/dirfilter ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/konq-plugins/dirfilter ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kbabel ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kbabel ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kalarm ; rm -rf common )
@@ -476,14 +524,20 @@
 ( cd opt/kde/share/doc/HTML/et/kommander ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kiconedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kiconedit ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kmahjongg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kmahjongg ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/klettres ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/klettres ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kfouleggs ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kfouleggs ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/xsldbg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/xsldbg ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kghostview ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kghostview ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/klickety ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/klickety ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kfilereplace ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kfilereplace ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kpovmodeler ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kpovmodeler ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kleopatra ; rm -rf common )
@@ -492,8 +546,6 @@
 ( cd opt/kde/share/doc/HTML/et/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kenolaba ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kenolaba ; ln -sf /opt/kde/share/doc/HTML/et/common common )
-( cd opt/kde/share/doc/HTML/et/kgpgcertmanager ; rm -rf common )
-( cd opt/kde/share/doc/HTML/et/kgpgcertmanager ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kwatchgnupg ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kwatchgnupg ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kworldclock ; rm -rf common )
@@ -536,6 +588,8 @@
 ( cd opt/kde/share/doc/HTML/et/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kinfocenter/pcmcia ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kinfocenter/opengl ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kinfocenter/opengl ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kinfocenter/processor ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kinfocenter/ioports ; rm -rf common )
